@@ -72,7 +72,7 @@ class App():
 
         # If a config file is specified, load all config from there instead
         if (args.__dict__["config"] != None):
-            config['config_path'] = args["config"]
+            config['config_path'] = args.__dict__["config"]
 
         if os.path.exists( config['config_path'] ):
             userConfig = json.load( file(config['config_path']) )
